#
# spec file for package python-freezerclient
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-freezerclient
Version:        5.2.0
Release:        1.1
Summary:        Python API and CLI for OpenStack Freezer
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/python-freezerclient
Source0:        https://files.pythonhosted.org/packages/source/p/python-freezerclient/python-freezerclient-5.2.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-cliff >= 2.8.0
BuildRequires:  python3-fixtures
BuildRequires:  python3-keystoneauth1 >= 3.4.0
BuildRequires:  python3-oslo.serialization >= 2.25.0
BuildRequires:  python3-oslo.utils >= 3.33.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-python-subunit
BuildRequires:  python3-stestr
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
Client library for Freezer built on the Freezer API. It provides a Python API
(the freezerclient module) and a command-line tool (freezer).

%package -n python3-freezerclient
Summary:        Python API and CLI for OpenStack Freezer
Requires:       python3-cliff >= 2.8.0
Requires:       python3-keystoneauth1 >= 3.4.0
Requires:       python3-oslo.serialization >= 2.25.0
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-pbr >= 2.0.0
%if 0%{?suse_version}
Obsoletes:      python2-freezerclient < 3.0.0
%endif

%description -n python3-freezerclient
Client library for Freezer built on the Freezer API. It provides a Python API
(the freezerclient module) and a command-line tool (freezer).

This package contains the Python 3.x module.

%package -n python-freezerclient-doc
Summary:        Documentation for OpenStack Freezer API client libary
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-freezerclient-doc
Client library for Freezer built on the Freezer API. It provides a Python API
(the freezerclient module) and a command-line tool (freezer).
This package contains the documentation.

%prep
%autosetup -p1 -n %{name}-%{version}
%py_req_cleanup

%build
%{py3_build}

# Build HTML docs and man page
PBR_VERSION=5.2.0 %sphinx_build -b html doc/source doc/build/html
rm -r doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
%{openstack_stestr_run}

%files -n python3-freezerclient
%doc README.rst
%license LICENSE
%{python3_sitelib}/freezerclient
%{python3_sitelib}/*.egg-info
%{_bindir}/freezer

%files -n python-freezerclient-doc
%doc doc/build/html
%license LICENSE

%changelog
* Wed Jan 10 2024 cloud-devel@suse.de
- update to version 5.2.0
  - Dropped the python 3.6/3.7 in zed cycle testing runtime
  - Drop lower-constraints.txt and its testing
  - Update arm ci jobs
  - Add zed test jobs
* Tue May 24 2022 cloud-devel@suse.de
- update to version 4.4.0
  - Add type hint for Client API
  - update type hint for Client
  - Fix flake8 error: H104
  - Add arm64 gate ci job
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 4.3.0
  - [ussuri][goal] Update contributor documentation
  - Fix lower-constraints CI error
  - Use py3 as the default runtime for tox
* Sun May  2 2021 cloud-devel@suse.de
- update to version 4.2.0
  - Update gate jobs
  - Restore package metadata
  - Remove unuseful param 'opts'
  - update package metadata
  - Add py38 package metadata.
  - Remove unsueful 'opts' param
  - Update package metadata
  - Update testing to Ubuntu Focal
  - Add "project_domain_id" param for clinet.Client():
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 4.0.0
  - Add py38 in tox.
  - Switch to newer openstackdocstheme and reno versions
  - Fix tip error
  - Use unittest.mock instead of third party mock
  - Add Python3 victoria unit tests
  - Remove keystone v2 related code
  - Update hacking for Python3
  - Fix hacking min version to 3.0.1
  - Update master for stable/ussuri
* Tue May 12 2020 cloud-devel@suse.de
- update to version 3.0.1
  - Blacklist sphinx 2.1.0 (autodoc bug)
  - Modify "backup-list" show
  - Update tox.ini file to add py36 in envlist
  - Remove six usage from freezerclient package
  - Upgrade pylint&astroid to a version that works with python3.7
  - Cleanup py27 support
  - result is different from comments
  - Add Python 3 Train unit tests
  - [ussuri][goal] Drop python 2.7 support and testing
* Tue Mar 10 2020 Dirk Mueller <dmueller@suse.com>
- Switch to a python 3.x only build
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 2.2.0
  - Change openstack-dev to openstack-discuss
  - Use template for lower-constraints
  - Bump the openstackdocstheme extension to 1.20
  - Update master for stable/stein
  - Dropping the py35 testing
  - Change openstack-dev to openstack-discuss in setup.cfg
  - Switch to the new canonical constraints URL on master
  - add python 3.7 unit test job
  - OpenDev Migration Patch
  - Replace git.openstack.org URLs with opendev.org URLs
  - Update json module to jsonutils
  - Update sphinx dependency
  - Add python3.7 unit test job
  - self.endpoint repeated
  - modify 'v1' in the comment to 'v2'
  - Update the bugs link to storyboard
  - Add Python 3.6 classifier to setup.cfg
  - delete repeated self.endpoint
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 2.1.0
  - Freezer command line tool add argument: "--os-backup-api-version"
  - Add 'freezerclient.v2.managers.clients' unit test cases
  - Switch to stestr
  - Add freezerclient.client in order to use the python api directly
  - Remove PyPI downloads
  - import zuul job settings from project-config
  - Update freezerclient documentation
  - Remove "--os-identity-api-version" argument
  - Add some unit test cases for API version 2
  - The path of the import module is incorrect
  - Add backup create client support for freezer
  - Add release note link in README
  - session-show status and result error, and add session_tag
  - add action show command field for freezerclient
  - Use keystoneauth1.loading instead of specifying V2 or V3 of keystone
  - Update min tox version to 2.0
  - Don't quote {posargs} in tox.ini
  - add show job command field for client v1
  - add python 3.6 unit test job
  - 'Tenant' is replaced by 'project' in keystone starting in API version 3.
  - add action show command field for client v1
  - Add py36 testenv
  - Trivial: Update pypi url to new url
  - Add 'freezerclient.v2.managers.jobs' unit test cases
  - Add backup create for api v1
  - Add the describes about search option
  - switch documentation job to new PTI
  - fix tox python3 overrides
  - Correct search opt param in SessionList
  - add show job command field for freezerclient
  - Freezerclient use "token" to authentication is not success
  - Add detailed information fro session-show and session-list for v1
  - Add freezer-tempest-client job as check/gate test job
  - Add 'freezerclient.v2.managers.sessions' unit test cases
  - Add detailed information fro session-show and session-list
  - add backup show command field for freezerclient
* Tue Sep  4 2018 cloud-devel@suse.de
- update to version 1.7.0
  - Update reno for stable/queens
  - Update links in README
  - Get project_id from session if not set using cli
  - Abstract Freezerclient Object creation
  - Follow the new PTI for document build
  - Updated from global requirements
  - add lower-constraints job
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 1.6.0 (bsc#1078607)
  - Remove the python-subunit from test-requirements.txt
  - Update reno for stable/pike
  - Remove setting of version/release from releasenotes
  - Use namespace to allow CommandManager to load actions
  - Fix creating freezer client with keystone auth session
  - Remove astroid from test-requirements
  - Avoid tox_install.sh for constraints support
  - Update wrong url for freezerclient
  - Fix guess auth version error
  - Updated from global requirements
  - Update cli reference
* Thu Jan 18 2018 tbechtold@suse.com
- Convert to singlespec
* Wed Aug 23 2017 tbechtold@suse.com
- add 0001-Remove-astroid-from-test-requirements.patch
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.5.0
  - Enable some off-by-default checks
  - Drop MANIFEST.in
  - Fix ssl connections
  - Fix 'freezer client-delete' error
  - [Fix gate]Update test requirement
  - Replace http with https
  - Update reno for stable/ocata
  - Remove unused components from requirements
  - Set OS_BACKUP_API_VERSION to v1
  - Use bindep to define binary deps
  - Import cli-reference content from openstack-manuals
  - Update message for job start/stop/abort
  - Enable client deletion
  - Update python-freezerclient for pike goal python 3.5
  - Added session-start option to allow starting sessions
  - Fix freezer client-* output
  - Fix SSL connections initiated from freezer-scheduler
  - Added obj file to delete at testenv
  - Change author in setup.cfg
  - Freezerclient v2
  - client-id is now required when creating jobs
  - Use pbr for version numbers
  - Enable project_id for multi-domain support
  - Follow up to I87f0add4dc2bcece832197cfc88e2d531a80a326
  - Displaying job status
  - Remove py34 from tox
  - Update documentation URLs
  - Deletion of backup metadata
  - Updated from global requirements
  - Switch to openstackdocstheme
* Mon Mar 27 2017 tbechtold@suse.com
- Initial package (version 1.3.0)
